@@ -4,11 +4,10 @@ import datetime
 import functools
 import json
 import logging
-import sys
 import time
-import traceback as tb
 import uuid
 
+from google.api_core import retry
 from google.cloud import pubsub_v1
 
 import octue.exceptions
@@ -18,6 +17,7 @@ from octue.cloud.pub_sub.logging import GooglePubSubHandler
 from octue.cloud.pub_sub.message_handler import OrderedMessageHandler
 from octue.mixins import CoolNameable
 from octue.utils.encoders import OctueJSONEncoder
+from octue.utils.exceptions import convert_exception_to_primitives
 from octue.utils.objects import get_nested_attribute
 
 
@@ -145,10 +145,11 @@ class Service(CoolNameable):
                         "type": "result",
                         "output_values": analysis.output_values,
                         "output_manifest": serialised_output_manifest,
-                        "message_number": str(topic.messages_published),
+                        "message_number": topic.messages_published,
                     },
                     cls=OctueJSONEncoder,
                 ).encode(),
+                retry=retry.Retry(deadline=timeout),
             )
             topic.messages_published += 1
             logger.info("%r responded to question %r.", self, question_uuid)
@@ -236,6 +237,7 @@ class Service(CoolNameable):
             data=json.dumps({"input_values": input_values, "input_manifest": serialised_input_manifest}).encode(),
             question_uuid=question_uuid,
             forward_logs=str(int(subscribe_to_logs)),
+            retry=retry.Retry(deadline=timeout),
         )
 
         # Keep a record of the question asked in case it needs to be retried.
@@ -323,9 +325,10 @@ class Service(CoolNameable):
                 {
                     "type": "delivery_acknowledgement",
                     "delivery_time": str(datetime.datetime.now()),
-                    "message_number": str(topic.messages_published),
+                    "message_number": topic.messages_published,
                 }
             ).encode(),
+            retry=retry.Retry(deadline=timeout),
         )
 
         topic.messages_published += 1
@@ -346,9 +349,10 @@ class Service(CoolNameable):
                 {
                     "type": "monitor_message",
                     "data": json.dumps(data),
-                    "message_number": str(topic.messages_published),
+                    "message_number": topic.messages_published,
                 }
             ).encode(),
+            retry=retry.Retry(deadline=timeout),
         )
 
         topic.messages_published += 1
@@ -360,22 +364,21 @@ class Service(CoolNameable):
         :param float|None timeout: time in seconds to keep retrying sending of the exception
         :return None:
         """
-        exception_info = sys.exc_info()
-        exception = exception_info[1]
-        exception_message = f"Error in {self!r}: {exception}"
-        traceback = tb.format_list(tb.extract_tb(exception_info[2]))
+        exception = convert_exception_to_primitives()
+        exception_message = f"Error in {self!r}: {exception['message']}"
 
         self.publisher.publish(
             topic=topic.path,
             data=json.dumps(
                 {
                     "type": "exception",
-                    "exception_type": type(exception).__name__,
+                    "exception_type": exception["type"],
                     "exception_message": exception_message,
-                    "traceback": traceback,
-                    "message_number": str(topic.messages_published),
+                    "traceback": exception["traceback"],
+                    "message_number": topic.messages_published,
                 }
             ).encode(),
+            retry=retry.Retry(deadline=timeout),
         )
 
         topic.messages_published += 1
