@@ -3,6 +3,7 @@ import logging
 import warnings
 
 import twined.exceptions
+from octue.cloud import storage
 from octue.definitions import OUTPUT_STRANDS
 from octue.exceptions import InvalidMonitorMessage
 from octue.mixins import Hashable, Identifiable, Labelable, Serialisable, Taggable
@@ -104,7 +105,7 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
 
         self._handle_monitor_message(data)
 
-    def finalise(self, output_dir=None, save_locally=False, upload_to_cloud=False, project_name=None, bucket_name=None):
+    def finalise(self, output_dir=None, save_locally=False, upload_to_cloud=False, cloud_path=None, bucket_name=None):
         """Validate and serialise the output values and manifest, optionally writing them to files and/or the manifest
         to the cloud.
 
@@ -114,12 +115,6 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
         :param str bucket_name:
         :return dict: serialised strings for values and manifest data.
         """
-        if project_name:
-            warnings.warn(
-                message="The `project_name` parameter is no longer needed and will be removed soon.",
-                category=DeprecationWarning,
-            )
-
         serialised_strands = {}
 
         for output_strand in OUTPUT_STRANDS:
@@ -147,8 +142,19 @@ class Analysis(Identifiable, Serialisable, Labelable, Taggable):
         # Optionally write the manifest to Google Cloud storage.
         if upload_to_cloud:
             if hasattr(self, "output_manifest"):
-                self.output_manifest.to_cloud(bucket_name, output_dir)
-                logger.debug("Wrote %r to cloud storage bucket %r.", self.output_manifest, bucket_name)
+                if not cloud_path:
+                    warnings.warn(
+                        message=(
+                            "Using a bucket name and path in bucket will be deprecated soon. Please use `cloud_path` instead e.g."
+                            "'gs://bucket_name/path/to/file.txt'."
+                        ),
+                        category=DeprecationWarning,
+                    )
+
+                    cloud_path = storage.path.generate_gs_path(bucket_name, output_dir)
+
+                self.output_manifest.to_cloud(cloud_path)
+                logger.debug("Wrote %r to %r.", self.output_manifest, cloud_path)
 
         return serialised_strands
 
